geowatch.tasks.uky\_temporal\_prediction.fit module
===================================================

.. automodule:: geowatch.tasks.uky_temporal_prediction.fit
   :members:
   :undoc-members:
   :show-inheritance:
